@@ -160,12 +160,6 @@ class Artifact(object):
 
     def tempfile(self, ext, rel_to_artifacts_dir = True):
         open(self.temp_filename(ext, rel_to_artifacts_dir), "w")
-    
-    def temp_dir(self):
-        os.path.join(self.artifacts_dir, self.hashstring)
-
-    def create_temp_dir(self):
-        os.path.mkdir(self.temp_dir())
 
 ### @export "create-input-file"
     def create_input_file(self, key, ext, rel_to_artifacts_dir = False):
