@@ -18,7 +18,7 @@ class JirbHandler(handlers.pexpect_handlers.ProcessLinewiseInteractiveHandler):
     EXECUTABLE = "/usr/bin/env jirb --prompt-mode simple"
     INPUT_EXTENSIONS = [".rb"]
     PROMPT = ">>|\?>"
-    OUTPUT_EXTENSIONS = [".rbcon"]
+    OUTPUT_EXTENSIONS = [".txt"]
     ALIASES = ['jirb']
 
 ### @export "jython-handler"
@@ -37,21 +37,3 @@ class JythonInteractiveHandler(handlers.pexpect_handlers.ProcessLinewiseInteract
     OUTPUT_EXTENSIONS = [".pycon"]
     ALIASES = ['jythoni']
 
-### @export "java-handler"
-class JavaHandler(DexyHandler):
-    VERSION = "/usr/bin/env java -version"
-    INPUT_EXTENSIONS = [".java"]
-    OUTPUT_EXTENSIONS = [".txt"]
-    ALIASES = ['java']
-    
-    def process(self):
-        print "original file name: ", self.doc.name
-        command = "/usr/bin/env javac %s" % (self.doc.name)
-        self.log.debug(command)
-        output = pexpect.run(command)
-        self.artifact.stdout = output
-        self.log.debug("\n%s" % output)
-        
-        command = "%s > %s" % (o_filename, self.artifact.filename)
-        self.artifact.data_dict['1'] = pexpect.run(command)
-
